
package dlog;

/**
 * Application for receiving and logging data points over Internet.
 * 
 * @author Johan Hagelbäck (johan.hagelback@lnu.se)
 */
public class Main 
{

    /**
     * Arguments:
     * Set port to start server at: -port=9090
     * Set path to log file: -logfile=data.csv
     * Set another csv file separator than semicolon: -separator=,
     * 
     * @param args the command line arguments
     */
    public static void main(String[] args) 
    {
        int port = 9090;
        String filename = "data.csv";
        String separator = ";";
        
        try
        {
            for (String arg : args)
            {
                // Port
                if (arg.startsWith("-port"))
                {
                    String[] t = arg.split("=");
                    port = Integer.parseInt(t[1]);
                }
                // Log file path
                if (arg.startsWith("-logfile"))
                {
                    String[] t = arg.split("=");
                    filename = t[1];
                    if (!filename.contains("."))
                    {
                        //Add file ending if not found
                        filename = filename + ".csv";
                    }
                }
                // Separator
                if (arg.startsWith("-separator"))
                {
                    String[] t = arg.split("=");
                    separator = t[1];
                    FileLogger.separator = separator;
                }
            }
        }
        catch (Exception ex)
        {
            System.err.println("Invalid arguments");
            System.exit(1);
        }
        
        System.out.println("Settings:");
        System.out.println("  Port: " + port);
        System.out.println("  Log file: " + filename);
        if (!separator.equals(";")) System.out.println("  Separator: " + separator);
        
        DLServer server = new DLServer(port, filename);
        server.start();
    }
}
